yt.data_objects.construction_data_containers.YTSmoothedCoveringGridBase.write_to_gdf — The yt Project 3.2-dev documentation

# yt.data_objects.construction_data_containers.YTSmoothedCoveringGridBase.write_to_gdf

`YTSmoothedCoveringGridBase.` `write_to_gdf`(gdf_path, fields, nprocs=1, field_units=None, **kwargs)

  Write the covering grid data to a GDF file.

  Parameters: | gdf_path : string Pathname of the GDF file to write. fields : list of strings Fields to write to the GDF file. nprocs : integer, optional Split the covering grid into nprocs subgrids before writing to the GDF file. Default: 1 field_units : dictionary, optional Dictionary of units to convert fields to. If not set, fields are in their default units. All remaining keyword arguments are passed to : yt.utilities.grid_data_format.writer.write_to_gdf. :

  Examples

      >>> cube.write_to_gdf("clumps.h5", ["density","temperature"], nprocs=16,
      ...                   clobber=True)